<?php
/*
Plugin Name: Bee5 Extended Plugin
Plugin URI: http://mabraham.de
Description: Just a small extension of the plugin Bee5Links written by Johannes Lauter (http://www.sparwelt.de/). The plugin marks affiliate links as advertisment by adding indicative text, so (german) law is observed. In addition a specified CSS-class is added to the affiliate links. Also the original links are save inside the title-attribute of the anchor-element. Therefore, you are able to restore original links at any time.
Version: v1.0
Author: Martin Abraham
Author URI: http://mabraham.de
License: GPL2

This plugin requires the plugin Bee5Links to be installed. You can download it at http://www.bee5.de. The plugin Bee5Links must be deactivated. 
There is no additional option page. If you want to change the marks or the CSS-class added to affiliate links, you have to change them directly inside the class.

*/

if(!class_exists("Bee5Links") && file_exists(dirname(__FILE__) . '/../bee5/bee5-plugin.php')){
	require_once dirname(__FILE__) . '/../bee5/bee5-plugin.php';
}

if (!class_exists("Bee5LinksExtended") && class_exists("Bee5Links")) {
	
	class Bee5LinksExtended extends Bee5Links {
		
		/* This are the marks for affiliate links, AFFILIATE_MARK_BEFORE is added in front of the link's text, AFFILIATE_MARK_AFTER is added behind. 
		 * Change the value directly inside the class 
		 */
		const AFFILIATE_MARK_BEFORE = '';
		const AFFILIATE_MARK_AFTER = ' (Partnerlink)';
		
		/* This is the CSS-class added to the class attribute of the affiliate link */
		const AFFILIATE_LINK_CLASS = 'bee5link';
		
		function addContent($content = '') {
			
			/* Fetch all links */
			preg_match_all('#\<a(.*)\shref\=(\\\"|")([^"]+)(\\\"|")(.*)\>(.*)\<\/a\>#iU', $content, $links, PREG_SET_ORDER);
			
			
			foreach($links as $link){
				
				$url = $link[3];
				
				/* Query API */
				$usedata['link'] = $url;
				$xml_link_awnser = $this->getAPIData('getlink', $this->getAdminOptions(), $usedata);
				
				/* If bee5 supports the given url */
				if(!preg_match('/^ERROR/', $xml_link_awnser)) {
					$xml = simplexml_load_string($xml_link_awnser);
					if(isset( $xml->bee5link)){
						
						$text = $link[6];
						$attributes1 = $link[1];
						$attributes2 = $link[5];
						
						
						/* If set, link's title attribute is replaced */
						$attributes1 = trim(preg_replace('#title=\\\"(.*)\\\"#iU', "", $attributes1));
						$attributes2 = trim(preg_replace('#title=\\\"(.*)\\\"#Ui', "title=\\\"$url\\\"", $attributes2, 1, $titleAttribute));

						/* If not set, title attribute is appended */
						if(!$titleAttribute){
							$attributes2 = $attributes2." title=\\\"$url\\\"";
						}
						$attributes2 = trim($attributes2);
						
						
						/* If the class attribute is set, append constant AFFILIATE_LINK_CLASS to the class attribute */
						$attributes1 = trim(preg_replace('#\sclass=\\\"(.*)\\\"#iU',' class=\\"$1 '. self::AFFILIATE_LINK_CLASS .'\\"' , ' '.$attributes1, 1, $classAttribute));
						if(!$classAttribute){
							$attributes2 = trim(preg_replace('#\sclass=\\\"(.*)\\\"#iU',' class=\\"$1 '. self::AFFILIATE_LINK_CLASS .'\\"' , ' '.$attributes2, 1, $classAttribute));
						}
						
						/* If not set, append AFFILIATE_LINK_CLASS to the end of the class attribute */
						if(!$classAttribute){
							$attributes2 = $attributes2 . " class=\\\"" . self::AFFILIATE_LINK_CLASS . "\\\"";
						}
						
						$newlink = "<a $attributes1 href=\\\"{$xml->bee5link}\\\" $attributes2>" . self::AFFILIATE_MARK_BEFORE . "{$text}" .self::AFFILIATE_MARK_AFTER. "</a>";
						$content = str_replace($link[0], $newlink, $content);
					}
				}
				
			}
			return $content;
		}
	}
}
if (class_exists("Bee5LinksExtended")) {
	$obj_bee5linksext = new Bee5LinksExtended();
}

/* Remove the Bee5Links' filter and replace it with the new version */
if (isset($obj_bee5linksext)) {
	remove_filter('content_save_pre', array(&$oj_bee5links, 'addContent'));
	add_filter('content_save_pre', array(&$obj_bee5linksext, 'addContent'));
}